@@ -29,7 +29,6 @@
 #include <QLabel>
 #include <QLayout>
 #include <QLineEdit>
-#include <QLinkedList>
 #include <QListWidget>
 #include <QPixmap>
 #include <QPushButton>
@@ -41,7 +40,6 @@
 // KDE Frameworks
 #include "kimagemapeditor_debug.h"
 #include <KConfigGroup>
-#include <KIconLoader>
 #include <KLocalizedString>
 #include <KSharedConfig>
 
@@ -603,12 +601,6 @@ HTMLPreviewDialog::HTMLPreviewDialog(QWidget* parent, const QString & htmlCode)
 
   htmlPart = new QWebEngineView;
   mainLayout->addWidget(htmlPart);
-//  htmlView = new KHTMLView(htmlPart, page);
-//  mainLayout->addWidget(htmlView);
-//  htmlView->setVScrollBarMode(QScrollView::Auto);
-//  htmlView->setHScrollBarMode(QScrollView::Auto);
-//  dialog->resize(dialog->calculateSize(edit->maxLineWidth(),edit->numLines()*));
-//	dialog->adjustSize();
   htmlPart->load(QUrl::fromLocalFile(tempFile->fileName()));
   QLabel *lbl = new QLabel;
   lbl->setObjectName( "urllabel" );
